@@ -75,6 +75,12 @@ class Client:
     def handle_response(self, response):
         if response.status_code == 200:
             return self.decode_response(response)
+        elif response.status_code == 400:
+            try:
+                error = response.json()["error"]
+            except (KeyError, ValueError):
+                error = "Bad Request"
+            raise ValueError(error)
         elif response.status_code == 403:
             raise FireflyError("Authorization token mismatch.")
         elif response.status_code == 404:
@@ -96,7 +102,9 @@ class Client:
             return response.json()
 
 def RemoteFunction(client, func_name):
-    def wrapped(**kwargs):
+    def wrapped(*args, **kwargs):
+        if args:
+            raise FireflyError('Firefly functions only accept named arguments')
         return client.call_func(func_name, **kwargs)
     wrapped.__name__ = func_name
     wrapped.__qualname__ = func_name
